package com.persistencia.jdbc;

import java.sql.Connection;
import java.sql.Date;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;

/**
 * Esta es una demo de accesos a base de datos Oracle y MSSQL Server mediante
 * Hibernate y JDBC
 * 
 * La clase debe parametrizarse mediante las constantes definidas al comienzo
 * 
 * En los siguientes métodos se implementan insert y selects para cada caso
 * 
 * @author JAVIER
 * 
 */
public class DemoQueriesJdbc {

	final static String ORACLE_DRIVER = "oracle.jdbc.driver.OracleDriver";

	final static String ORACLE_JDBC_URL = "jdbc:oracle:thin:@192.168.1.20:1521:qemu";

	final static String ORACLE_USERNAME = "test";

	final static String ORACLE_PASSWORD = "test";

	final static String ORACLE_SCHEMA = "TEST.";

	final static String MSSQL_DRIVER = "com.microsoft.sqlserver.jdbc.SQLServerDriver";

	final static String MSSQL_JDBC_URL = "jdbc:sqlserver://192.168.1.18:1433";

	final static String MSSQL_USERNAME = "sa";

	final static String MSSQL_PASSWORD = "misecreto";

	final static String MSSQL_SCHEMA = "";

	final static long DAY_IN_MILLIS = 1000 * 60 * 60 * 24;

	public void queriesJdbc(String jdbcDriver, String jdbcUrl, String userName,
			String password, String schema) throws Exception {
		// Cargar el driver
		System.out.println("   - Cargar el driver");
		Class.forName(jdbcDriver);
		// Crear una conexión
		System.out.println("   - Crear una conexión");
		Connection con = DriverManager.getConnection(jdbcUrl, userName,
				password);
		// Crear un Statement para obtener el máximo id
		System.out.println("   - Crear un Statement para obtener el máximo id");
		Statement stmt = con.createStatement();
		ResultSet rs = stmt.executeQuery("SELECT MAX(id) FROM " + schema
				+ "DEMO_QUERIES");
		int id = 0;
		if (rs.next()) {
			id = rs.getInt(1) + 1;
		}
		rs.close();
		stmt.close();
		// Crear un PreparedStatement para insert
		System.out.println("   - Crear un PreparedStatement para insert");
		PreparedStatement prepareInsert = con.prepareStatement("INSERT INTO "
				+ schema + "DEMO_QUERIES (id, nombre, fecha) VALUES (?, ?, ?)");
		System.out.println("   - Completar sus atributos");
		int i = 1;
		prepareInsert.setInt(i++, id);
		prepareInsert.setString(i++, "Ejemplo JDBC");
		prepareInsert.setDate(i++, new Date((new java.util.Date()).getTime()));
		System.out.println("   - Ejecutar el insert");
		prepareInsert.executeUpdate();
		prepareInsert.close();
		// Crear un PreparedStatement para select
		System.out.println("   - Crear un PreparedStatement para select");
		PreparedStatement prepareSelect = con
				.prepareStatement("SELECT id, nombre, fecha FROM " + schema
						+ "DEMO_QUERIES WHERE fecha < ?");
		System.out.println("   - Completar sus atributos");
		prepareSelect.setDate(1, new Date((new java.util.Date()).getTime()
				+ DAY_IN_MILLIS));
		System.out.println("   - Ejecutar la select");
		rs = prepareSelect.executeQuery();
		while (rs.next()) {
			System.out.println("     o Id = " + rs.getInt(1) + " - nombre = "
					+ rs.getString(2) + " - fecha = " + rs.getDate(3) + "");
		}
		rs.close();
		prepareSelect.close();
		System.out.println("   - Fin\n\n");
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		System.out.println(" * Iniciando demo de queries JDBC\n");
		DemoQueriesJdbc demoQueries = new DemoQueriesJdbc();
		try {
			System.out.println(" * Ejecutando demo Oracle con JDBC...\n");

			demoQueries.queriesJdbc(ORACLE_DRIVER, ORACLE_JDBC_URL,
					ORACLE_USERNAME, ORACLE_PASSWORD, ORACLE_SCHEMA);

			System.out.println(" * Ejecutando demo MS SQL con JDBC...\n");

			demoQueries.queriesJdbc(MSSQL_DRIVER, MSSQL_JDBC_URL,
					MSSQL_USERNAME, MSSQL_PASSWORD, MSSQL_SCHEMA);

		} catch (Exception e) {
			System.out.println(" * Ha ocurrido el siguiente error:");
			e.printStackTrace();
		}
	}

}
